@@ -7,7 +7,6 @@
 #include "manager.h"
 #include "dbushelper.h"
 #include "device.h"
-#include "enum.h"
 #include "libkbolt_debug.h"
 #include "managerinterface.h"
 
@@ -19,13 +18,15 @@ Manager::Manager(QObject *parent)
     : QObject(parent)
     , mInterface(std::make_unique<ManagerInterface>(DBusHelper::serviceName(), QStringLiteral("/org/freedesktop/bolt"), DBusHelper::connection()))
 {
+    qDBusRegisterMetaType<QDBusObjectPath>();
+
     if (!mInterface->isValid()) {
         qCWarning(log_libkbolt, "Failed to connect to Bolt manager DBus interface: %s", qUtf8Printable(mInterface->lastError().message()));
         return;
     }
 
     connect(mInterface.get(), &ManagerInterface::DeviceAdded, this, [this](const QDBusObjectPath &path) {
-        if (auto device = Device::create(path)) {
+        if (auto device = Device::create(path, this)) {
             mDevices.push_back(device);
             qCDebug(log_libkbolt,
                     "New Thunderbolt device %s (%s) added, status=%s",
@@ -45,7 +46,7 @@ Manager::Manager(QObject *parent)
 
     const auto devicePaths = mInterface->ListDevices().argumentAt<0>();
     for (const auto &devicePath : devicePaths) {
-        if (auto device = Device::create(devicePath)) {
+        if (auto device = Device::create(devicePath, this)) {
             qCDebug(log_libkbolt,
                     "Discovered Thunderbolt device %s (%s), status=%s",
                     qUtf8Printable(device->uid()),
